@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2018 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -623,7 +623,7 @@ def attackDumpedTable():
         col_passwords = set()
         attack_dict = {}
 
-        for column in columns:
+        for column in sorted(columns, key=lambda _: len(_), reverse=True):
             if column and column.lower() in COMMON_USER_COLUMNS:
                 col_user = column
                 break
@@ -1078,7 +1078,8 @@ def dictionaryAttack(attack_dict):
                         gc.enable()
 
                     if retVal:
-                        conf.hashDB.beginTransaction()
+                        if conf.hashDB:
+                            conf.hashDB.beginTransaction()
 
                         while not retVal.empty():
                             user, hash_, word = item = retVal.get(block=False)
@@ -1086,7 +1087,8 @@ def dictionaryAttack(attack_dict):
                             hashDBWrite(hash_, word)
                             results.append(item)
 
-                        conf.hashDB.endTransaction()
+                        if conf.hashDB:
+                            conf.hashDB.endTransaction()
 
             clearConsoleLine()
 
@@ -1171,15 +1173,17 @@ def dictionaryAttack(attack_dict):
                         if _multiprocessing:
                             gc.enable()
 
-                        if retVal:
-                            conf.hashDB.beginTransaction()
+                        if retVal and conf.hashDB:
+                            if conf.hashDB:
+                                conf.hashDB.beginTransaction()
 
                             while not retVal.empty():
                                 user, hash_, word = item = retVal.get(block=False)
                                 hashDBWrite(hash_, word)
                                 results.append(item)
 
-                            conf.hashDB.endTransaction()
+                            if conf.hashDB:
+                                conf.hashDB.endTransaction()
 
                 clearConsoleLine()
 
@@ -1194,3 +1198,17 @@ def dictionaryAttack(attack_dict):
         logger.warn(warnMsg)
 
     return results
+
+def crackHashFile(hashFile):
+    i = 0
+    attack_dict = {}
+
+    for line in getFileItems(conf.hashFile):
+        if ':' in line:
+            user, hash_ = line.split(':', 1)
+            attack_dict[user] = [hash_]
+        else:
+            attack_dict["%s%d" % (DUMMY_USER_PREFIX, i)] = [line]
+            i += 1
+
+    dictionaryAttack(attack_dict)
