@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2017 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -44,7 +44,7 @@ class Fingerprint(GenericFingerprint):
         value += "active fingerprint: %s" % actVer
 
         if kb.bannerFp:
-            banVer = kb.bannerFp["dbmsVersion"] if 'dbmsVersion' in kb.bannerFp else None
+            banVer = kb.bannerFp.get("dbmsVersion")
             banVer = Format.getDbms([banVer])
             value += "\n%sbanner parsing fingerprint: %s" % (blank, banVer)
 
@@ -80,6 +80,10 @@ class Fingerprint(GenericFingerprint):
 
                 return False
 
+            # Determine if it is Informix >= 11.70
+            if inject.checkBooleanExpression("CHR(32)=' '"):
+                Backend.setVersion(">= 11.70")
+
             setDbms(DBMS.INFORMIX)
 
             self.getBanner()
