@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2018 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -368,16 +368,16 @@ class Enumeration(GenericEnumeration):
                             if foundTbl not in dbs[db]:
                                 dbs[db][foundTbl] = {}
 
-                            if colConsider == "1":
+                            if colConsider == '1':
                                 conf.db = db
                                 conf.tbl = foundTbl
                                 conf.col = column
 
                                 self.getColumns(onlyColNames=True, colTuple=(colConsider, colCondParam), bruteForce=False)
 
-                                if db in kb.data.cachedColumns and foundTbl in kb.data.cachedColumns[db]\
-                                  and not isNoneValue(kb.data.cachedColumns[db][foundTbl]):
+                                if db in kb.data.cachedColumns and foundTbl in kb.data.cachedColumns[db] and not isNoneValue(kb.data.cachedColumns[db][foundTbl]):
                                     dbs[db][foundTbl].update(kb.data.cachedColumns[db][foundTbl])
+
                                 kb.data.cachedColumns = {}
                             else:
                                 dbs[db][foundTbl][column] = None
